==> orca-2.18.1.tar.bz2: orca-2.18.1/src/orca/orca_state.py <==
# Orca
#
# Copyright 2006 Sun Microsystems Inc.
#
# This library is free software; you can redistribute it and/or
# modify it under the terms of the GNU Library General Public
# License as published by the Free Software Foundation; either
# version 2 of the License, or (at your option) any later version.
#
# This library is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Library General Public License for more details.
#
# You should have received a copy of the GNU Library General Public
# License along with this library; if not, write to the
# Free Software Foundation, Inc., 59 Temple Place - Suite 330,
# Boston, MA 02111-1307, USA.

"""Holds state that is shared among many modules.
"""

__id__        = "$Id: orca_state.py 1818 2006-12-13 01:21:31Z wwalker $"
__version__   = "$Revision: 1818 $"
__date__      = "$Date: 2006-12-12 20:21:31 -0500 (Tue, 12 Dec 2006) $"
__copyright__ = "Copyright (c) 2005-2006 Sun Microsystems Inc."
__license__   = "LGPL"

# NOTE: resist the temptation to do any imports here.  They can
# easily cause circular imports.
#

# The Accessible that has visual focus.
#
locusOfFocus = None

# The currently active window.
#
activeWindow = None

# The currently active script.
#
activeScript = None

# The "click" count. Used to determine if the user has double or triple
# "clicked" a key.
#
clickCount = 0

# Used to capture keys to redefine key bindings by the user.
#
capturingKeys   = False
lastCapturedKey = None

# The InputEvent instance representing the last input event.  This is
# set each time a mouse, keyboard or braille event is received.
#
lastInputEvent = None

# The last timestamp from a device event. Used to set focus for the Orca
# configuration GUI.
#
lastInputEventTimestamp = 0

# Records the last time a key was echoed.
#
lastKeyEchoTime = None

# The time that the last "No focus" event occured.
#
noFocusTimestamp = 0.0

# The last word spoken.
#
lastWord = ""

# The last searchQuery
#
searchQuery = None

==> orca-2.21.3.tar.bz2: orca-2.21.3/src/orca/orca_state.py <==
# Orca
#
# Copyright 2006 Sun Microsystems Inc.
#
# This library is free software; you can redistribute it and/or
# modify it under the terms of the GNU Library General Public
# License as published by the Free Software Foundation; either
# version 2 of the License, or (at your option) any later version.
#
# This library is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Library General Public License for more details.
#
# You should have received a copy of the GNU Library General Public
# License along with this library; if not, write to the
# Free Software Foundation, Inc., 59 Temple Place - Suite 330,
# Boston, MA 02111-1307, USA.

"""Holds state that is shared among many modules.
"""

__id__        = "$Id: orca_state.py 3263 2007-11-28 19:23:44Z eitani $"
__version__   = "$Revision: 3263 $"
__date__      = "$Date: 2007-11-28 14:23:44 -0500 (Wed, 28 Nov 2007) $"
__copyright__ = "Copyright (c) 2005-2006 Sun Microsystems Inc."
__license__   = "LGPL"

# NOTE: resist the temptation to do any imports here.  They can
# easily cause circular imports.
#

# History of focused accessibles, helps caching.
#
focusHistory = []

# The Accessible that has visual focus.
#
locusOfFocus = None

# The currently active window.
#
activeWindow = None

# The currently active script.
#
activeScript = None

# The "click" count. Used to determine if the user has double or triple
# "clicked" a key.
#
clickCount = 0

# Used to capture keys to redefine key bindings by the user.
#
capturingKeys   = False
lastCapturedKey = None

# The last non-modifier key event received.
#
lastNonModifierKeyEvent = None

# The InputEvent instance representing the last input event.  This is
# set each time a mouse, keyboard or braille event is received.
#
lastInputEvent = None

# The last timestamp from a device event. Used to set focus for the Orca
# configuration GUI.
#
lastInputEventTimestamp = 0

# Records the last time a key was echoed.
#
lastKeyEchoTime = None

# The time that the last "No focus" event occured.
#
noFocusTimestamp = 0.0

# The last word spoken.
#
lastWord = ""

# The last searchQuery
#
searchQuery = None

# Whether we should use the pronunciation dictionary to help speak 
# certain words. This will be True everywhere except when focus is 
# in the Pronunciation Dictionary in the Orca Preferences dialog.
#
usePronunciationDictionary = True

# Handle to the Orca Preferences Glade GUI object.
#
orcaOS = None

# Handle to the Orca application specific preferences Glade GUI object.
#
appOS = None

# Handle to the Glade warning dialog object that is displayed, if the 
# user has attempted to start a second instance of a preferences dialog.
#
orcaWD = None

# Handle to the Orca Preferenvces Glade file.
#
prefsGladeFile = None
